@@ -44,10 +44,10 @@ runPS :: IO [PsResult]
 runPS = snd <$> runResourceT (sourceCmdWithConsumer "ps -ef" consumer)
   where
     consumer = CB.lines
-            $= CL.map BS.words
-            $= CL.map toPsResult
-            $= CL.filter mighty
-            $= CL.consume
+            .| CL.map BS.words
+            .| CL.map toPsResult
+            .| CL.filter mighty
+            .| CL.consume
     commandName = last . split '/' . command
     mighty ps = "mighty" `BS.isInfixOf` name
              && not ("mightyctl" `BS.isInfixOf` name)
