@@ -11,7 +11,7 @@ import Data.Char (isSpace)
 import Data.List (dropWhile, dropWhileEnd, break)
 #endif
 import Data.Streaming.Network (bindPortTCP)
-import Network (Socket, sClose)
+import Network.Socket (Socket, close)
 import qualified Network.HTTP.Client as H
 import Network.Wai.Application.Classic hiding ((</>))
 import Network.Wai.Handler.Warp
@@ -142,7 +142,7 @@ getTlsSetting _opt =
                 key  <- BS.readFile $ opt_tls_key_file _opt
                 let settings0 = tlsSettingsChainMemory cert chains key
                     settings = settings0 {
-                        tlsSessionManagerConfig = Just defaultConfig
+                        tlsSessionManagerConfig = Just defaultConfig { dbMaxSize = 1000 }
                       }
                 return settings
 #else
@@ -218,17 +218,17 @@ openService :: Option -> IO Service
 openService opt
   | service == 1 = do
       s <- bindPortTCP httpsPort hostpref
-      debugMessage $ "HTTP/TLS service on port " ++ show httpsPort ++ "."
+      debugMessage $ urlForHTTPS httpsPort
       return $ HttpsOnly s
   | service == 2 = do
       s1 <- bindPortTCP httpPort hostpref
       s2 <- bindPortTCP httpsPort hostpref
-      debugMessage $ "HTTP service on port " ++ show httpPort ++ " and "
-                  ++ "HTTP/TLS service on port " ++ show httpsPort ++ "."
+      debugMessage $ urlForHTTP httpPort
+      debugMessage $ urlForHTTPS httpsPort
       return $ HttpAndHttps s1 s2
   | otherwise = do
       s <- bindPortTCP httpPort hostpref
-      debugMessage $ "HTTP service on port " ++ show httpPort ++ "."
+      debugMessage $ urlForHTTP httpPort
       return $ HttpOnly s
   where
     httpPort  = opt_port opt
@@ -239,13 +239,18 @@ openService opt
     debugMessage msg = when debug $ do
         putStrLn msg
         hFlush stdout
+    urlForHTTP  80  =  "http://localhost/"
+    urlForHTTP  p   =  "http://localhost:" ++ show p ++ "/"
+    urlForHTTPS 443 = "https://localhost/"
+    urlForHTTPS p   = "https://localhost:" ++ show p ++ "/"
+
 
 ----------------------------------------------------------------
 
 closeService :: Service -> IO ()
-closeService (HttpOnly s)         = sClose s
-closeService (HttpsOnly s)        = sClose s
-closeService (HttpAndHttps s1 s2) = sClose s1 >> sClose s2
+closeService (HttpOnly s)         = close s
+closeService (HttpsOnly s)        = close s
+closeService (HttpAndHttps s1 s2) = close s1 >> close s2
 
 ----------------------------------------------------------------
 
